﻿<?xml version="1.0" encoding="UTF-8"?>

<!-- request-query引数を使用するときにはネームスペースの宣言の記述を一部追加する必要があります -->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:fmrs="http://www.filemaker.com/xml/fmresultset"
                xmlns:fmq="http://www.filemaker.com/xml/query"
                exclude-result-prefixes="xsl fmrs fmq"
                version="1.0">

  <!-- 実際には1行で記述します -->
  <?xslt-cwp-query params="-grammar=fmresultset&-db=dbname&-lay=layoutname&-max=10&-find"?>

  <xsl:output doctype-public="-//W3C//DTD HTML 4.01 Transitional//EN" doctype-system="http://www.w3.org/TR/html4/loose.dtd" />

  <!-- FileMakerクエリー文字列の情報にアクセスするためにrequest-query引数を宣言します -->
  <xsl:param name="request-query" />

  <!-- 対象レコード数を変数countに格納します -->
  <xsl:variable name="count" select="/fmrs:fmresultset/fmrs:resultset/@count" />

  <!-- -maxクエリー引数の値を変数maxに格納します -->
  <xsl:variable name="max" select="$request-query/fmq:query/fmq:parameter[@name='-max']" />

  <!-- -skipクエリー引数の値を変数skipに格納します -->
  <xsl:variable name="skip">
    <xsl:choose>
      <xsl:when test="$request-query/fmq:query/fmq:parameter[@name='-skip']">
        <!-- -skipクエリー引数が指定されている場合は-skipクエリー引数の値を変数skipに格納します -->
        <xsl:value-of select="$request-query/fmq:query/fmq:parameter[@name='-skip']" />
      </xsl:when>
      <xsl:otherwise>
        <!-- -skipクエリー引数が指定されていない場合は変数skipの値を0にします -->
        <xsl:value-of select="0" />
      </xsl:otherwise>
    </xsl:choose>
  </xsl:variable>

  <xsl:template match="/">
    <html>
      <head>
        <title>sample030</title>
      </head>
      <body>
        <xsl:apply-templates />

        <!-- 変数skipの値が0より大きい場合に、前の範囲のレコードへのリンクを表示します -->
        <xsl:if test="$skip &gt; 0">
          <a href="{$request-query/fmq:query/@action}?-skip={$skip - $max}" class="prev" rel="prev">
            <xsl:text>前のレコードを表示</xsl:text>
          </a>
        </xsl:if>

        <!-- 最後のレコードのあるページ以外で、次の範囲のレコードへのリンクを表示します -->
        <xsl:if test="$skip + $max &lt; $count">
          <a href="{$request-query/fmq:query/@action}?-skip={$skip + $max}" class="next" rel="next">
            <xsl:text>次のレコードを表示</xsl:text>
          </a>
        </xsl:if>

      </body>
    </html>
  </xsl:template>

  <xsl:template match="/fmrs:fmresultset/fmrs:resultset/fmrs:record">
    <xsl:value-of select="fmrs:field[@name='field1']/fmrs:data" /><br />
  </xsl:template>

</xsl:stylesheet>