<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:fmrs="http://www.filemaker.com/xml/fmresultset"
                xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
                xmlns:dc="http://purl.org/dc/elements/1.1/"
                xmlns:rss="http://purl.org/rss/1.0/"
                xmlns:atom="http://www.w3.org/2005/Atom"
                exclude-result-prefixes="xsl fmrs rdf dc rss atom">

  <!-- RSS 1.0、RSS 2.0、Atom 1.0形式のフィードを取得・表示するサンプル -->

  <?xslt-cwp-query params="-grammar=fmresultset&-process"?>

  <xsl:output doctype-public="-//W3C//DTD HTML 4.01 Transitional//EN" doctype-system="http://www.w3.org/TR/html4/loose.dtd" />

  <xsl:template match="/">
    <html>
      <head>
        <title>sample043</title>
      </head>
      <body>
        <!-- RSS 1.0   -->
        <xsl:variable name="url" select="'http://www.filemaker.ne.jp/feed/'" />
		
        <!-- RSS 2.0   -->
		<!-- <xsl:variable name="url" select="'http://www.bnn.co.jp/index.xml'" /> -->
		
        <!-- Atom 1.0  -->
        <!-- <xsl:variable name="url" select="'http://www.bnn.co.jp/atom.xml'" /> -->

        <!-- document関数を使用してフィードを取得します -->
        <xsl:variable name="feeddata" select="document($url)" />

        <!-- フィードのタイトルを表示します -->
        <h1>
          <!-- RSS 1.0  -->
          <xsl:apply-templates select="$feeddata/rdf:RDF/rss:channel/rss:title" />
		  
          <!-- RSS 2.0  -->
          <xsl:apply-templates select="$feeddata/rss/channel/title" />
		  
           <!-- Atom 1.0 -->
          <xsl:apply-templates select="$feeddata/atom:feed/atom:title" />
        </h1>

        <!-- フィードに含まれるすべての記事のリンクとタイトルを表示します -->
        <!-- RSS 1.0  -->
        <xsl:apply-templates select="$feeddata/rdf:RDF/rss:item" />
		
        <!-- RSS 2.0  -->
        <xsl:apply-templates select="$feeddata/rss/channel/item" />
		
        <!-- Atom 1.0 -->
        <xsl:apply-templates select="$feeddata/atom:feed/atom:entry" />
      </body>
    </html>
  </xsl:template>

  <xsl:template match="rss:item">
    <!-- RSS 1.0 -->
    <xsl:call-template name="entry">
      <xsl:with-param name="title" select="rss:title" />
      <xsl:with-param name="link" select="rss:link" />
      <xsl:with-param name="datetime" select="dc:date" />
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="item">
    <!-- RSS 2.0 -->
    <xsl:call-template name="entry">
      <xsl:with-param name="title" select="title" />
      <xsl:with-param name="link" select="link" />
      <xsl:with-param name="datetime" select="pubDate" />
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="atom:entry">
    <!-- Atom 1.0 -->
    <xsl:call-template name="entry">
      <xsl:with-param name="title" select="atom:title" />
      <xsl:with-param name="link" select="atom:link/@href" />
      <xsl:with-param name="datetime" select="atom:updated" />
    </xsl:call-template>
  </xsl:template>

  <xsl:template name="entry">
    <!-- パラメーターを利用して共通する処理を1つにまとめる例 -->
    <xsl:param name="link" />
    <xsl:param name="title" />
    <xsl:param name="datetime" />

    <xsl:choose>
      <xsl:when test="starts-with($link, 'http://') or starts-with($link, 'https://')">
        <!-- リンク設定用の属性値としてURLを出力する場合には「http://」もしくは「https://」で始まっているか確認する必要があります -->
        <a>
          <xsl:attribute name="href">
            <!-- 記事のリンクをaタグのhref属性に設定します -->
            <xsl:value-of select="$link" />
          </xsl:attribute>

          <!-- 記事のタイトルを表示します -->
          <xsl:value-of select="$title" />
        </a>
      </xsl:when>
      <xsl:otherwise>
        <!-- URLが「http://」もしくは「https://」で始まっていない場合には記事のタイトルのみ表示します -->
        <xsl:value-of select="$title" />
      </xsl:otherwise>
    </xsl:choose>

    <!-- 記事の更新日時を表示します -->
    <xsl:text>（</xsl:text>
    <xsl:value-of select="$datetime" />
    <xsl:text>）</xsl:text>
    <br />
  </xsl:template>

</xsl:stylesheet>