﻿<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:fmrs="http://www.filemaker.com/xml/fmresultset"
                xmlns:fmq="http://www.filemaker.com/xml/query"
                xmlns:fmxslt="xalan://com.fmi.xslt.ExtensionFunctions"
                exclude-result-prefixes="xsl fmrs fmq fmxslt">

  <?xslt-cwp-buffer buffer-content="true"?>
  <?xslt-cwp-query params="-grammar=fmresultset&-process"?>

  <xsl:output doctype-public="-//W3C//DTD HTML 4.01 Transitional//EN" doctype-system="http://www.w3.org/TR/html4/loose.dtd" />

  <xsl:param name="request-query" />

  <!-- Basic認証のユーザー名とパスワードを取得するための引数 -->
  <xsl:param name="client-user-name" />
  <xsl:param name="client-password" />

  <xsl:template match="/">
    <xsl:choose>
      <xsl:when test="$client-user-name = 'guest' and $client-password = 'guest'">
        <!-- Basic認証による認証処理を通過した場合にコンテンツを表示するサンプルです -->
        <!-- （実際には、XSLTスタイルシートの中に直接ユーザー名やパスワードを埋め込まず、データベースと連動して作りこむことになります） -->
        <xsl:call-template name="content" />
      </xsl:when>
      <xsl:otherwise>
        <!-- 本サンプルではBasic認証のユーザー名とパスワードが入力されていない場合に認証を要求するようにしています -->
        <xsl:value-of select="fmxslt:set_status_code(401)" />
        <xsl:value-of select="fmxslt:set_header('WWW-Authenticate', 'Basic realm=&quot;input username/password = guest/guest &quot;')" />
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="content">
    <html>
      <head>
        <title>sample043b</title>
      </head>
      <body>
        <!-- 認証処理を通過した後にセッションを作成します -->
        <xsl:variable name="sessionname" select="'foo'" />
        <xsl:if test="fmxslt:session_exists($sessionname) = false()">
          <xsl:variable name="instantiating_session" select="fmxslt:create_session($sessionname)" />
          <!-- セッション作成時にセッション変数にユーザー名を保存しています -->
          <xsl:variable name="storing_a_username" select="fmxslt:set_session_object($sessionname, 'userid', $client-user-name)" />
        </xsl:if>

        <!-- -token.sessionidの値をセッションIDにしてPOSTメソッドでリクエストを送信するためのフォームを用意します -->
        <form action="{$request-query/fmq:query/@action}" method="POST">
          <!-- Cookieが無効の場合にはaction属性の値は「{fmxslt:session_encode_url($request-query/fmq:query/@action)}」にします -->
          <xsl:choose>
            <xsl:when test="string-length(fmxslt:get_cookie('JSESSIONID')) &gt; 0">
              <input type="hidden" name="-token.sessionid" value="{fmxslt:get_cookie('JSESSIONID')}" />
            </xsl:when>
            <xsl:otherwise>
              <input type="hidden" name="-token.sessionid" value="{substring-after(fmxslt:session_encode_url(''), 'jsessionid=')}" />
            </xsl:otherwise>
          </xsl:choose>
          <input type="submit" name="-token.submit" value="リクエストを実行" />
        </form>

        <xsl:if test="string-length($request-query/fmq:query/fmq:parameter[@name='-token.submit']) &gt; 0">
          <!-- フォームから送信されたリクエストが正常なものかチェックします -->

          <!-- -token.sessionidの値を変数sessionidに格納します -->
          <xsl:variable name="sessionid" select="$request-query/fmq:query/fmq:parameter[@name='-token.sessionid']" />

          <xsl:choose>
            <!-- フォームで指定した-token.sessionidの値とセッションIDが一致しているか調べます -->
            <xsl:when test="fmxslt:get_cookie('JSESSIONID') = $sessionid or substring-after(fmxslt:session_encode_url(''), 'jsessionid=') = $sessionid">
              <xsl:choose>
                <!-- セッション作成時にセットしたセッション変数の有無によりリクエストが正常であるか確認します -->
                <xsl:when test="string-length(fmxslt:get_session_object($sessionname, 'userid')) &gt; 0">
                  <p>リクエストは正常です</p>
                </xsl:when>
                <xsl:otherwise>
                  <!-- リクエストが正常でない場合のエラー処理をここに記述します -->
                  <p>エラーが発生しました</p>
                </xsl:otherwise>
              </xsl:choose>
            </xsl:when>
            <xsl:otherwise>
              <!-- リクエストが正常でない場合のエラー処理をここに記述します -->
              <p>エラーが発生しました</p>
            </xsl:otherwise>
          </xsl:choose>
        </xsl:if>

      </body>
    </html>
  </xsl:template>

</xsl:stylesheet>